Ext.namespace('Zarafa.plugins.owncloudattachment');

/**
 * @class Zarafa.plugins.owncloudattachment.OwncloudAttachmentPlugin
 * @extends Zarafa.core.Plugin
 * This class is used for adding files from the users's Owncloud folder
 * to his emails as attachments
 */
Zarafa.plugins.owncloudattachment.OwncloudAttachmentPlugin = Ext.extend(Zarafa.core.Plugin, {

	/**
	 * @constructor
	 * @param {Object} config
	 */
	constructor : function(config)
	{
		config = config || {};
		Ext.applyIf(config, {
			name : 'owncloudattachment'
		});
		
		Zarafa.plugins.owncloudattachment.OwncloudAttachmentPlugin.superclass.constructor.call(this, config);
	},

	/**
	 * initialises insertion point for plugin
	 * @protected
	 */
	initPlugin : function()
	{
		Zarafa.plugins.owncloudattachment.OwncloudAttachmentPlugin.superclass.initPlugin(this, arguments);
		this.registerInsertionPoint('main.attachment.method', this.onAttachmentInsertion)
		Zarafa.core.data.SharedComponentType.addProperty('common.dialog.attachments.owncloud');
		
		/* use zarafa user as default user */
		if(container.getSettingsModel().get('zarafa/v1/plugins/owncloudattachment/username') == "defaultusername") {
			container.getSettingsModel().set('zarafa/v1/plugins/owncloudattachment/username', container.getUser().getUserName());
		}
	},

	/**
	 * Insert owncloud option in all attachment suggestions
	 */
	onAttachmentInsertion : function(include, btn) {
		return {
			text : _('Owncloud'),
			handler : this.showOwncloudAttachmentDialog.createDelegate(this, [btn]),
			scope: this,
			iconCls: 'icon_owncloud'
		};
	},

	/**
	 * Initializes Dialog for adding attachment from Owncloud to email
	 * @param {Object} btn
	 * @private
	 */
	showOwncloudAttachmentDialog : function(btn)
	{
		Zarafa.core.data.UIFactory.openLayerComponent(Zarafa.core.data.SharedComponentType['common.dialog.attachments.owncloud'], btn.record, {
			title : _('Add attachment from Owncloud'),
			manager : Ext.WindowMgr
		});
	},
	
	/**
	 * Bid for the type of shared component
	 * and the given record.
	 * This will bid on calendar.dialogs.importevents
	 * @param {Zarafa.core.data.SharedComponentType} type Type of component a context can bid for.
	 * @param {Ext.data.Record} record Optionally passed record.
	 * @return {Number} The bid for the shared component
	 */
	bidSharedComponent : function(type, record)
	{
		var bid = -1;
		
		switch(type)
		{
			case Zarafa.core.data.SharedComponentType['common.dialog.attachments.owncloud']:
				if (record instanceof Zarafa.core.data.IPMRecord) {
					if (record.supportsAttachments()) {
						bid = 1;
					}
				}
				break;
		}
		return bid;
	},

	/**
	 * Will return the reference to the shared component.
	 * Based on the type of component requested a component is returned.
	 * @param {Zarafa.core.data.SharedComponentType} type Type of component a context can bid for.
	 * @param {Ext.data.Record} record Optionally passed record.
	 * @return {Ext.Component} Component
	 */
	getSharedComponent : function(type, record)
	{
		var component;

		switch(type)
		{
			case Zarafa.core.data.SharedComponentType['common.dialog.attachments.owncloud']:
				component = Zarafa.plugins.owncloudattachment.dialogs.AttachmentContentPanel;
				break;
		}

		return component;
	}	
});

/**
 * registers plugin
 */
Zarafa.onReady(function() {
	if(container.getSettingsModel().get('zarafa/v1/plugins/owncloudattachment/enable') === true)  {
		container.registerPlugin( new Zarafa.plugins.owncloudattachment.OwncloudAttachmentPlugin);
	}
});
